==> verticalpodautoscaler-model-v1-6.8.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerCheckpointStatusBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class VerticalPodAutoscalerCheckpointStatusBuilder extends VerticalPodAutoscalerCheckpointStatusFluent<VerticalPodAutoscalerCheckpointStatusBuilder> implements VisitableBuilder<VerticalPodAutoscalerCheckpointStatus,VerticalPodAutoscalerCheckpointStatusBuilder>{
  public VerticalPodAutoscalerCheckpointStatusBuilder() {
    this(false);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(Boolean validationEnabled) {
    this(new VerticalPodAutoscalerCheckpointStatus(), validationEnabled);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new VerticalPodAutoscalerCheckpointStatus(), validationEnabled);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent,VerticalPodAutoscalerCheckpointStatus instance) {
    this(fluent, instance, false);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent,VerticalPodAutoscalerCheckpointStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new VerticalPodAutoscalerCheckpointStatus());

    if (instance != null) {
      fluent.withCpuHistogram(instance.getCpuHistogram());
      fluent.withFirstSampleStart(instance.getFirstSampleStart());
      fluent.withLastSampleStart(instance.getLastSampleStart());
      fluent.withLastUpdateTime(instance.getLastUpdateTime());
      fluent.withMemoryHistogram(instance.getMemoryHistogram());
      fluent.withTotalSamplesCount(instance.getTotalSamplesCount());
      fluent.withVersion(instance.getVersion());
      fluent.withCpuHistogram(instance.getCpuHistogram());
      fluent.withFirstSampleStart(instance.getFirstSampleStart());
      fluent.withLastSampleStart(instance.getLastSampleStart());
      fluent.withLastUpdateTime(instance.getLastUpdateTime());
      fluent.withMemoryHistogram(instance.getMemoryHistogram());
      fluent.withTotalSamplesCount(instance.getTotalSamplesCount());
      fluent.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatus instance) {
    this(instance,false);
  }
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new VerticalPodAutoscalerCheckpointStatus());

    if (instance != null) {
      this.withCpuHistogram(instance.getCpuHistogram());
      this.withFirstSampleStart(instance.getFirstSampleStart());
      this.withLastSampleStart(instance.getLastSampleStart());
      this.withLastUpdateTime(instance.getLastUpdateTime());
      this.withMemoryHistogram(instance.getMemoryHistogram());
      this.withTotalSamplesCount(instance.getTotalSamplesCount());
      this.withVersion(instance.getVersion());
      this.withCpuHistogram(instance.getCpuHistogram());
      this.withFirstSampleStart(instance.getFirstSampleStart());
      this.withLastSampleStart(instance.getLastSampleStart());
      this.withLastUpdateTime(instance.getLastUpdateTime());
      this.withMemoryHistogram(instance.getMemoryHistogram());
      this.withTotalSamplesCount(instance.getTotalSamplesCount());
      this.withVersion(instance.getVersion());
    }
    this.validationEnabled = validationEnabled; 
  }
  VerticalPodAutoscalerCheckpointStatusFluent<?> fluent;
  Boolean validationEnabled;
  public VerticalPodAutoscalerCheckpointStatus build() {
    VerticalPodAutoscalerCheckpointStatus buildable = new VerticalPodAutoscalerCheckpointStatus(fluent.buildCpuHistogram(),fluent.getFirstSampleStart(),fluent.getLastSampleStart(),fluent.getLastUpdateTime(),fluent.buildMemoryHistogram(),fluent.getTotalSamplesCount(),fluent.getVersion());
    return buildable;
  }
  
}

==> verticalpodautoscaler-model-v1-6.10.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/VerticalPodAutoscalerCheckpointStatusBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class VerticalPodAutoscalerCheckpointStatusBuilder extends VerticalPodAutoscalerCheckpointStatusFluent<VerticalPodAutoscalerCheckpointStatusBuilder> implements VisitableBuilder<VerticalPodAutoscalerCheckpointStatus,VerticalPodAutoscalerCheckpointStatusBuilder>{
  public VerticalPodAutoscalerCheckpointStatusBuilder() {
    this(new VerticalPodAutoscalerCheckpointStatus());
  }
  
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent) {
    this(fluent, new VerticalPodAutoscalerCheckpointStatus());
  }
  
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatusFluent<?> fluent,VerticalPodAutoscalerCheckpointStatus instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public VerticalPodAutoscalerCheckpointStatusBuilder(VerticalPodAutoscalerCheckpointStatus instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  VerticalPodAutoscalerCheckpointStatusFluent<?> fluent;
  
  public VerticalPodAutoscalerCheckpointStatus build() {
    VerticalPodAutoscalerCheckpointStatus buildable = new VerticalPodAutoscalerCheckpointStatus(fluent.buildCpuHistogram(),fluent.getFirstSampleStart(),fluent.getLastSampleStart(),fluent.getLastUpdateTime(),fluent.buildMemoryHistogram(),fluent.getTotalSamplesCount(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
